| plot.classes | R Documentation |
plot functions to generate visual representations for the outputs of several fitting functions: FASSMR.kernel.fit, FASSMR.kNN.fit, fsim.kernel.fit, fsim.kernel.fit.optim, fsim.kNN.fit, fsim.kNN.fit.optim, IASSMR.kernel.fit, IASSMR.kNN.fit, lm.pels.fit, PVS.fit, PVS.kernel.fit, PVS.kNN.fit, sfpl.kernel.fit, sfpl.kNN.fit,sfplsim.kernel.fit and sfplsim.kNN.fit.
## S3 method for class 'FASSMR.kernel'
plot(x,ind=1:10, size=15,col1=1,col2=2,col3=4,option=0,...)
## S3 method for class 'FASSMR.kNN'
plot(x,ind=1:10, size=15,col1=1,col2=2,col3=4,option=0, ...)
## S3 method for class 'fsim.kernel'
plot(x,size=15,col1=1,col2=2, ...)
## S3 method for class 'fsim.kNN'
plot(x,size=15,col1=1,col2=2,...)
## S3 method for class 'IASSMR.kernel'
plot(x,ind=1:10, size=15,col1=1,col2=2,col3=4,option=0, ...)
## S3 method for class 'IASSMR.kNN'
plot(x,ind=1:10, size=15,col1=1,col2=2,col3=4,option=0, ...)
## S3 method for class 'lm.pels'
plot(x,size=15,col1=1,col2=2,col3=4, ...)
## S3 method for class 'PVS'
plot(x,ind=1:10, size=15,col1=1,col2=2,col3=4,option=0, ...)
## S3 method for class 'PVS.kernel'
plot(x,ind=1:10, size=15,col1=1,col2=2,col3=4,option=0, ...)
## S3 method for class 'PVS.kNN'
plot(x,ind=1:10, size=15,col1=1,col2=2,col3=4,option=0, ...)
## S3 method for class 'sfpl.kernel'
plot(x,size=15,col1=1,col2=2,col3=4, ...)
## S3 method for class 'sfpl.kNN'
plot(x,size=15,col1=1,col2=2,col3=4, ...)
## S3 method for class 'sfplsim.kernel'
plot(x,size=15,col1=1,col2=2,col3=4, ...)
## S3 method for class 'sfplsim.kNN'
plot(x,size=15,col1=1,col2=2,col3=4, ...)
x |
Output of the functions mentioned in the |
ind |
Indexes of the colors for the curves in the chart of estimated impact points. The default is |
size |
The size for title and axis labels in pts. The default is 15. |
col1 |
Color of the points in the charts. Also, color of the estimated functional index representation. The default is black. |
col2 |
Color of the nonparametric fit representation in FSIM functions, and of the straight line in 'Response vs Fitted Values' charts. The default is red. |
col3 |
Color of the nonparametric fit of the residuals in 'Residuals vs Fitted Values' charts. The default is blue. |
option |
Selection of charts to be plotted. The default, |
... |
Further arguments passed to or from other methods. |
The functions return different graphical representations.
For the classes fsim.kNN and fsim.kernel:
The estimated functional index: \hat{\theta}.
The regression fit.
For the classes lm.pels, sfpl.kernel and sfpl.kNN:
The response over the fitted.values.
The residuals over the fitted.values.
For the classes sfplsim.kernel and sfplsim.kNN:
The estimated functional index: \hat{\theta}.
The response over the fitted.values.
The residuals over the fitted.values.
For the classes FASSMR.kernel, FASSMR.kNN, IASSMR.kernel, IASSMR.kNN, sfplsim.kernel and sfplsim.kNN:
If option=1: The curves with the estimated impact points (in dashed vertical lines).
If option=2: The estimated functional index: \hat{\theta}.
If option=3:
The response over the fitted.values.
The residuals over the fitted.values.
If option=0: All chart are plotted.
For the classes PVS, PVS.kNN, PVS.kernel:
If option=1: The curves with the estimated impact points (in dashed vertical lines).
If option=2:
The response over the fitted.values.
The residuals over the fitted.values.
If option=0: All chart are plotted.
All the routines implementing the plot S3 method use internally the R package ggplot2 to produce elegant and high quality
charts.
German Aneiros Perez german.aneiros@udc.es
Silvia Novo Diaz snovo@est-econ.uc3m.es
FASSMR.kernel.fit, FASSMR.kNN.fit, fsim.kernel.fit, fsim.kNN.fit, IASSMR.kernel.fit, IASSMR.kNN.fit, lm.pels.fit, PVS.fit, PVS.kernel.fit, PVS.kNN.fit, sfpl.kernel.fit, sfpl.kNN.fit, sfplsim.kernel.fit and sfplsim.kNN.fit.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.