| print.summary.mfplsim | R Documentation |
summary and print functions for FASSMR.kernel.fit, FASSMR.kNN.fit, IASSMR.kernel.fit and IASSMR.kNN.fit.
## S3 method for class 'FASSMR.kernel'
print(x, ...)
## S3 method for class 'FASSMR.kNN'
print(x, ...)
## S3 method for class 'IASSMR.kernel'
print(x, ...)
## S3 method for class 'IASSMR.kNN'
print(x, ...)
## S3 method for class 'FASSMR.kernel'
summary(object, ...)
## S3 method for class 'FASSMR.kNN'
summary(object, ...)
## S3 method for class 'IASSMR.kernel'
summary(object, ...)
## S3 method for class 'IASSMR.kNN'
summary(object, ...)
x |
Output of the |
... |
Further arguments passed to or from other methods. |
object |
Output of the |
The matched call.
The optimal value of the tunning parameter (h.opt or k.opt).
The optimal initial number of covariates to build the reduced model (w.opt).
Coefficients of \hat{\theta} in the B-spline basis (theta.est): a vector of length(order.Bspline+nknot.theta).
The estimated vector of linear coefficients (beta.est).
The number of non-zero components in beta.est.
The indexes of the non-zero components in beta.est.
The optimal value of the penalisation parameter (lambda.opt).
The optimal value of the criterion function, i.e. the value obtained with w.opt, lambda.opt, vn.opt and h.opt/k.opt
Minimum value of the penalised least-squares function. That is, the value obtained using theta.est, beta.est and lambda.opt.
The penalty function used.
The criterion used to select the number of covariates employed to construct the reduced model, the tuning parameter, the penalisation parameter and vn.
German Aneiros Perez german.aneiros@udc.es
Silvia Novo Diaz snovo@est-econ.uc3m.es
FASSMR.kernel.fit, FASSMR.kNN.fit, IASSMR.kernel.fit and IASSMR.kNN.fit.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.